#ifndef __GFXENV_VDC0_H__
#define __GFXENV_VDC0_H__

#include "GfxEnv.h"

/** this class is used as the GfxEnv for the vdc0 (running on RZ/A1-devices)
*/
class CGfxEnvVDC0 : public CGfxEnv
{
public:
    /** Create Instance
    @param eSurfaceMode surface-mode
    @param eScreenFormat screen-format
    @param uiWidth width
    @param uiHeight height
    @param uiBufferCount number of buffers to use
    @param ppkBuffers buffers
    @param bResizable true if resizable
    @return true if successful
    */
    static eC_Bool CreateInstance(
        const SurfaceMode_t& eSurfaceMode,
        const CGUICommonEnums::ImageType_t& eScreenFormat,
        const eC_UInt& uiWidth,
        const eC_UInt& uiHeight,
        const eC_UInt& uiBufferCount,
        void** ppkBuffers,
        const eC_Bool& bResizable = false);
    
    virtual void InitLayer(const LayerConfiguration_t& kLayerInfo);

    virtual void EndOfRefresh();
    virtual eC_Bool RefreshScreen(const CGUIRect& rkInvalidatedArea);
    
    virtual ~CGfxEnvVDC0();

private:
    /** constructor
    @param eSurfaceMode surface-mode
    @param eScreenFormat screen-format
    @param uiWidth width
    @param uiHeight height
    @param uiBufferCount number of buffers to use
    @param ppkBuffers buffers
    @param bResizable true if resizable
    */
    CGfxEnvVDC0(
        const SurfaceMode_t& eSurfaceMode,
        const CGUICommonEnums::ImageType_t& eScreenFormat,
        const eC_UInt& uiWidth,
        const eC_UInt& uiHeight,
        const eC_UInt& uiBufferCount = 1,
        void** ppkBuffers = NULL,
        const eC_Bool& bResizable = false);

    /** Copy-constructor.
        @param kSource Source object to be copied.
    */
    CGfxEnvVDC0(const CGfxEnvVDC0& kSource);

    /** Operator= method.
        @param kSource Source object to be copied.
        @return This instance.
    */
    CGfxEnvVDC0& operator=(const CGfxEnvVDC0& kSource);
    
    void CopyBuffer(int iX1, int iY1, int iRectWidth, int iRectHeight);
};

#endif
