/*
* Copyright (C) 2004 TES Electronic Solutions GmbH,
* All Rights Reserved.
* This source code and any compilation or derivative thereof is the
* proprietary information of TES Electronic Solutions GmbH
* and is confidential in nature.
* Under no circumstances is this software to be exposed to or placed
* under an Open Source License of any type without the expressed
* written permission of TES Electronic Solutions GmbH
*
*############################################################
*/

/******************************************************************************
 Includes   <System Includes> , "Project Includes"
 ******************************************************************************/
extern "C"
{
#include <ctype.h>

#include "FreeRTOS.h"
#include "task.h"
#include "r_typedefs.h"
#include "r_vdc_portsetting.h"
#include "compiler_settings.h"
#include "r_rvapi_header.h"
#include "r_display_init.h"
#include "string.h"
}

/******************************************************************************
 Macro definitions
 ******************************************************************************/
/* diplay layer for rectangle */
#if defined GFX_USE_RGB565
#define DATA_SIZE_PER_PIC      (2u)
#elif defined GFX_USE_ARGB32
#define DATA_SIZE_PER_PIC      (4u)
#else
#error "Set bits per pixel"
#endif

#define FRAMEBUFFER_WIDTH   FRAME_BUFFER_WIDTH
#define FRAMEBUFFER_HEIGHT  FRAME_BUFFER_HEIGHT

#define FRAMEBUFFER_LAYER_NUM      (2u)
#define FRAMEBUFFER_STRIDE  (((FRAMEBUFFER_WIDTH * DATA_SIZE_PER_PIC) + 31u) & ~31u)

extern "C"
{
uint8_t framebuffer[FRAMEBUFFER_LAYER_NUM][FRAMEBUFFER_STRIDE * FRAMEBUFFER_HEIGHT] __attribute__ ((section(".VRAM_SECTION0")));

volatile uint8_t *RZAFrameBuffers[2] =
{
    framebuffer[1],
    framebuffer[0],
};

/******************************************************************************
 Private global variables and functions
 ******************************************************************************/

/******************************************************************************
 Imported global variables and functions (from other files)
 ******************************************************************************/
#if defined(PLATFORM_RENESAS_DISPLAYIT_V2) || defined(PLATFORM_RENESAS_GRPEACH)
extern void v7_flush_kern_dcache_area(void *addr, size_t size);
#endif

/****************************************************************************/
/* VRAM definitions															*/
/****************************************************************************/
static volatile int32_t vsync_count = 0;
static int draw_buffer_index = 0;

/* explcit function for cache-access */
unsigned int ClearDataCache(void* ptr, uint32_t size)
{
#if defined(PLATFORM_RENESAS_DISPLAYIT_V2) || defined(PLATFORM_RENESAS_GRPEACH)
    v7_flush_kern_dcache_area(ptr, size);
#endif

    return 0;
}

#if( configAPPLICATION_ALLOCATED_HEAP == 1 )
    extern volatile uint8_t ucHeap[ configTOTAL_HEAP_SIZE ];
#endif

void* GetHeapStart()
{
#if( configAPPLICATION_ALLOCATED_HEAP == 1 )
    return (void*)&ucHeap[0];
#else
    #error "no heap allocated"
    return NULL;
#endif
}

void* GetHeapEnd()
{
#if( configAPPLICATION_ALLOCATED_HEAP == 1 )
    return (void*)((uint8_t*)&ucHeap[0] + configTOTAL_HEAP_SIZE);
#else
    #error "no heap allocated"
    return NULL;
#endif
}
}
